package com.joa.backend.controller;

import com.joa.backend.constant.HttpStatus;
import com.joa.backend.entity.SysUser;
import com.joa.backend.service.ISysUserService;
import com.joa.backend.utils.ResponseResult;
import com.joa.backend.utils.SecurityUtils;
import com.joa.backend.utils.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/sys/user")
public class SysUserController extends BaseController{
    protected final Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private ISysUserService userService;

    @GetMapping("/list")
    public ResponseResult list(SysUser sysUser){
        return new ResponseResult(HttpStatus.SUCCESS,"请求成功",userService.selectSysUserAll(sysUser));
    }

    @PostMapping
    public ResponseResult add(@RequestBody SysUser sysUser){
        if (!userService.checkUserNameUnique(sysUser)){
            return error("新增用户："+sysUser.getUserName()+"失败，登陆账号已存在");
        }
        else if (StringUtils.isNotEmpty(sysUser.getPhone()) && !userService.checkPhoneUnique(sysUser)) {
            return error("新增用户："+sysUser.getUserName()+"失败，手机号码已存在");
        }else if (StringUtils.isNotEmpty(sysUser.getEmail()) && !userService.checkEmailUnique(sysUser)){
            return error("新增用户："+sysUser.getUserName()+"失败，邮箱账号已存在");
        }
        sysUser.setCreateBy(SecurityUtils.getLoginUser().getUsername());
        sysUser.setPassword(SecurityUtils.encryptPassword(sysUser.getPassword()));
        return toResult(userService.insertSysUser(sysUser));
    }
}
